@@ -1,19 +1,24 @@
 use Apache ();
-use Cwd 'getcwd';
 my $tests = 0;
-my $pwd = getcwd;
 
 my $r = Apache->request;
 $r->content_type("text/html");
 $r->send_http_header;
-my $doc_root = "$pwd/../../docs";
-#Apache->untaint($doc_root);
+my $doc_root = $r->document_root;
 
 my $ht_access  = "$doc_root/.htaccess";
 my $hooks_file = "$doc_root/hooks.txt";
 
-unlink $ht_access;
-unlink $hooks_file;
+sub wipe_file {
+    local *FH;
+    open FH, ">$_[0]";
+    print FH " ";
+    close FH;
+}
+
+for ($ht_access, $hooks_file) {
+    wipe_file($_);
+}
 
 local *FH;
 if(Apache::perl_hook("Authen")) {
