@@ -10,6 +10,7 @@
 #PerlSendHeader On
 #PerlSetupEnv   On
 
+my $r = shift;
 my $sub = "test_$ENV{QUERY_STRING}";
 if (defined &{$sub}) {
     &{$sub};
@@ -22,7 +23,9 @@ else {
     print "Content-type: text/plain\n\n";
 
     print "perlio test...\n";
-    print "\$^X is $^X\n";
+    print "\$^X is $^X\n" if $^X;
+    my $loc = $r->location;
+    print "<Location $loc>\n";
     my(@args);
 
     if (@args = split(/\+/, $ENV{QUERY_STRING})) {
